import {useToast}from'@chakra-ui/toast';import jwtDecode from'jwt-decode';import React__default from'react';import {useQueryClient,useMutation}from'react-query';import {validateToken,authenticate,register}from'../API.js';const AuthContext = React__default.createContext({});
// TODO: Refactoring: Get user from localStorage
const AuthProvider = ({ children }) => {
    const [isLoading, setIsLoading] = React__default.useState(false);
    const [user, setUser] = React__default.useState();
    const [token, setToken] = React__default.useState(localStorage.getItem("token"));
    useQueryClient();
    const toast = useToast();
    /**
     * Check for token in localStorage
     */
    React__default.useEffect(() => {
        const tokenStorage = localStorage.getItem("token");
        if (tokenStorage) {
            validateToken(tokenStorage).then(res => {
                console.log("validating...");
                if (res.status !== 200)
                    return logoutAsync("Token expired");
            });
            setToken(tokenStorage);
        }
        else {
            loginAsync({ email: "test@mail.com", password: "password" });
        }
    }, []);
    React__default.useEffect(() => {
        if (token) {
            const decodedUser = jwtDecode(token);
            setUser({
                email: decodedUser.email,
                name: decodedUser.name,
                roles: decodedUser.roles,
                token: token,
                userId: decodedUser.userId,
            });
        }
    }, [token]);
    const updateToken = (token) => {
        setToken(token);
    };
    const mutateLogin = useMutation(authenticate, {
        onSuccess: (res) => {
            setToken(res.data.token);
            localStorage.setItem("token", res.data.token);
            toast({ description: "Logged in successfully", status: "success", duration: 3000 });
        },
        onError: (res) => { toast({ description: res.data.message, status: "error", duration: 3000 }); },
        onSettled: () => setIsLoading(false)
    });
    const mutateRegister = useMutation(register, {
        onSuccess: (res) => {
            // setUser(res.data);
            setToken(res.data.token);
            localStorage.setItem("token", res.data.token);
            toast({ description: "Logged in successfully", status: "success", duration: 3000 });
        },
        onError: (res) => {
            console.log(res.data);
            for (let i = 0; i < res.data.messages.length; i++) {
                toast({ description: res.data.messages[i], status: "error", duration: 3000 });
            }
        },
        onSettled: () => setIsLoading(false)
    });
    const logoutAsync = async (msg) => {
        await new Promise(resolve => setTimeout(resolve, 1000));
        setUser(undefined);
        setToken(null);
        localStorage.removeItem("token");
        toast({
            title: msg ? msg : "Logged out successfully!",
            isClosable: true,
            duration: 3000,
            status: "success"
        });
        await new Promise(resolve => setTimeout(resolve, 500));
    };
    const loginAsync = async (request) => {
        setIsLoading(true);
        await new Promise(resolve => setTimeout(resolve, 1000));
        try {
            mutateLogin.mutate(request);
        }
        catch (e) {
            console.log(e);
        }
        finally {
            setIsLoading(false);
        }
    };
    const registerAsync = async (request) => {
        setIsLoading(true);
        await new Promise(resolve => setTimeout(resolve, 1000));
        try {
            mutateRegister.mutate(request);
        }
        catch (error) {
            console.log(error);
        }
        finally {
            setIsLoading(false);
        }
    };
    return (React__default.createElement(AuthContext.Provider, { value: {
            loginAsync: loginAsync,
            logoutAsync: logoutAsync,
            updateToken: updateToken,
            isLoading: isLoading,
            user: user,
            registerAsync: registerAsync
        } }, children));
};export{AuthContext,AuthProvider};//# sourceMappingURL=AuthContext.js.map
