import {__rest}from'tslib';import {useToast,useMediaQuery,Box,Flex,Button}from'@chakra-ui/react';import React__default from'react';import DayPicker,{DateUtils}from'react-day-picker';import {useFela}from'react-fela';import {styleSheet}from'./styles.js';const getDatesBetween = (fromDate, toDate) => {
    const from = new Date(fromDate);
    const to = new Date(toDate);
    let datesBtw = [];
    let start = from;
    start.setDate(start.getDate() + 1);
    while (start.getDate() < to.getDate()) {
        datesBtw.push(new Date(start));
        start.setDate(start.getDate() + 1);
    }
    return datesBtw;
};
const getDisabledDates = (schedules) => {
    let disabledDates = [];
    if (schedules === null || schedules === void 0 ? void 0 : schedules.reservedDates) {
        for (let i = 0; i < schedules.reservedDates.length; i++) {
            disabledDates.push(...getDatesBetween(schedules.reservedDates[i].fromDate, schedules.reservedDates[i].toDate));
        }
    }
    if (schedules === null || schedules === void 0 ? void 0 : schedules.dayOff)
        disabledDates.push(...schedules.dayOff);
    return disabledDates;
};
const getDateCheckOutOnly = (schedules) => {
    var _a;
    return (_a = schedules === null || schedules === void 0 ? void 0 : schedules.reservedDates) === null || _a === void 0 ? void 0 : _a.map(r => new Date(r.fromDate));
};
const getNextPossibleDate = (day, schedules) => {
    let nextDay = undefined;
    if (schedules === null || schedules === void 0 ? void 0 : schedules.reservedDates) {
        schedules.reservedDates.forEach(r => {
            const rFrom = new Date(r.fromDate);
            if (rFrom > day) {
                if (!nextDay)
                    nextDay = rFrom;
                else if (rFrom <= nextDay)
                    nextDay = rFrom;
            }
        });
    }
    if (nextDay !== day)
        return nextDay;
    return null;
};
const defaultDate = {
    from: undefined,
    to: undefined,
    enteredTo: undefined
};
const PickRangeDay = (props) => {
    const { from, to, updateDate, schedules } = props, boxProps = __rest(props, ["from", "to", "updateDate", "schedules"]);
    const toast = useToast();
    const [state, setState] = React__default.useState({ from: from, to: to });
    const disabled = [
        {
            before: new Date(Date.now())
        },
        ...getDisabledDates(schedules),
    ];
    const [disabledDays, setDisabledDays] = React__default.useState(disabled);
    React__default.useEffect(() => {
        if ((state.from && state.to) || (!state.from && !state.to)) {
            updateDate(state.from, state.to);
        }
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [state.from, state.to]);
    const isSelectingFirstDay = (day, from, to) => {
        const isBeforeFirstDay = from && DateUtils.isDayBefore(day, from);
        const isRangeSelected = from && to;
        return !from || isBeforeFirstDay || isRangeSelected;
    };
    const handleDayMouseEnter = (day) => {
        const { from, to } = state;
        if (!isSelectingFirstDay(day, from, to)) {
            setState(s => (Object.assign(Object.assign({}, s), { enteredTo: day })));
        }
    };
    const handleDayClick = (day, modifiers) => {
        var _a;
        if (modifiers.disabled)
            return;
        const today = new Date(Date.now());
        if (day < today)
            return;
        const { from, to } = state;
        if (from && to && day >= from && day <= to) {
            handleResetClick();
            return;
        }
        // if selecting first day, recalculate disabled days to this chosen day
        if (isSelectingFirstDay(day, from, to)) {
            if (modifiers.checkoutOnly) {
                toast({
                    status: "info",
                    description: "Check out only!",
                    duration: 3000
                });
                return;
            }
            setDisabledDays((s) => (Object.assign(Object.assign({}, s), { before: day, after: getNextPossibleDate(day, schedules) })));
            setState({
                from: day,
                to: undefined,
                enteredTo: undefined,
            });
        }
        // else, set every things back to normal
        else {
            setDisabledDays(disabled);
            // prevent from = to
            if (((_a = state.from) === null || _a === void 0 ? void 0 : _a.getDate()) === day.getDate()) {
                setState({
                    from: undefined,
                    to: undefined,
                    enteredTo: undefined,
                });
                return;
            }
            setState(s => (Object.assign(Object.assign({}, s), { to: day, enteredTo: day })));
        }
    };
    const handleResetClick = () => {
        setState(defaultDate);
    };
    const selected = [state.from, { from: state.from, to: state.enteredTo }];
    const modifiers = {
        start: state.from,
        end: state.enteredTo,
        checkoutOnly: getDateCheckOutOnly(schedules),
    };
    const [enoughFor2MonthsDisplay] = useMediaQuery("(min-width: 600px)");
    const { css } = useFela();
    return (React__default.createElement(Box, Object.assign({ d: "flex", flexDir: "column" }, boxProps, { overflow: "clip" }),
        React__default.createElement(Box, { alignSelf: "center", className: css(styleSheet.dayPickerStyle) },
            React__default.createElement(DayPicker, { numberOfMonths: enoughFor2MonthsDisplay ? 2 : 1, fromMonth: state.from, modifiers: modifiers, onDayClick: handleDayClick, disabledDays: disabledDays, onDayMouseEnter: handleDayMouseEnter, selectedDays: selected })),
        React__default.createElement(Flex, { justifyContent: "center", alignItems: "center" },
            !state.from && !state.to && 'Please select the first day.',
            state.from && !state.to && 'Please select the last day.',
            state.from &&
                state.to &&
                `Selected from ${state.from.toLocaleDateString()} to
                ${state.to.toLocaleDateString()}`,
            ' ',
            state.from && state.to && (React__default.createElement(Button, { onClick: handleResetClick }, "Reset")))));
};export default PickRangeDay;export{getDatesBetween};//# sourceMappingURL=PickRangeDay.js.map
